@@ -16,6 +16,10 @@ pub extern crate derive_more;
 macro_rules! derive_id {
 	($id_newtype:item) => {
 		#[cfg_attr(feature = "graphql", derive(async_graphql::NewType))]
+		#[cfg_attr(
+			not(feature = "graphql"),
+			derive($crate::derive_more::From, $crate::derive_more::Into)
+		)]
 		#[cfg_attr(
 			feature = "diesel-id",
 			derive($crate::diesel_derive_newtype::DieselNewType)
